Skip to contents

This function plots the response curves along with the optimal points determined by the optimization results.

Usage

plot_optimal_mix(optimal_mix)

Arguments

response_funs

A named list of response functions.

res

The result object from the optimization containing the optimal solution.

Value

A ggplot object showing the response curves and optimal points.