Helper function to set default priors for scaled data
hlpr_default_prior_for_scaled_data.RdThis function sets default priors for the parameters of the four-parameter logistic model when the data has been scaled. The priors are based on the expected range of the parameters after scaling.