Helper function to scale the data for model prep
hlpr_scale_data.RdThis function scales the data using min-max scaling and also calculates the inferred x-range for the model. It returns a list containing the scaled data, the inferred x-range, and the min-max values used for scaling.