Set a total constraint function
hlpr_set_total_constraint.RdThis function creates a constraint function that ensures the sum of the elements in a vector equals a specified total.
hlpr_set_total_constraint.RdThis function creates a constraint function that ensures the sum of the elements in a vector equals a specified total.